@@ -27,14 +27,14 @@ SPDX-License-Identifier: GPL-3.0-only
 from sys import version_info
 
 from . import __description__, __epilog__, __version__
-from .pprint import BLUE, BRIGHT, GREEN, MAGENTA, RESET
 
 
-def pinfo(emacs):
+def pinfo(emacs, pprint):
     """!
     Print short info about the program.
 
     @param emacs: a Emacs object
+    @param emacs: a Pprint object
     """
 
     python_version = f"{version_info.major}.{version_info.minor}"
@@ -45,9 +45,14 @@ def pinfo(emacs):
         emacs_version = "unknown"
 
     print(
-        f"{BRIGHT}{GREEN}ETask{RESET}, " +
-        f"{__description__}, version {GREEN}{__version__}{RESET}, " +
-        f"running on {BRIGHT}{BLUE}Python {python_version}{RESET} " +
-        f"and {BRIGHT}{MAGENTA}GNU Emacs {emacs_version}{RESET}"
+        f"{pprint.bright}{pprint.green}ETask{pprint.reset}, " +
+        f"{__description__}," +
+        " " +
+        f"version {pprint.green}{__version__}{pprint.reset}, " +
+        f"running on {pprint.bright}{pprint.blue}Python" +
+        " " +
+        f"{python_version}{pprint.reset} " +
+        f"and {pprint.bright}{pprint.magenta}GNU Emacs {emacs_version}" +
+        f"{pprint.reset}"
     )
     print(__epilog__)
